{#advlink_dlg.title}

- {#advlink_dlg.general_tab}
- {#advlink_dlg.advanced_tab}

{#advlink_dlg.general_props}
{#advlink_dlg.url}
{#advlink_dlg.list}
{#advlink_dlg.anchor_names}
{#advlink_dlg.target}
{#advlink_dlg.titlefield}
{#class_name}
{#advlink_dlg.popup_props}
{#advlink_dlg.popup}
{#advlink_dlg.popup_url}
{#advlink_dlg.popup_name}
{#advlink_dlg.popup_size} x px
{#advlink_dlg.popup_position} / (c /c = center)
{#advlink_dlg.popup_location}
{#advlink_dlg.popup_scrollbars}
{#advlink_dlg.popup_menubar}
{#advlink_dlg.popup_resizable}
{#advlink_dlg.popup_toolbar} {#advlink_dlg.popup_dependent}
{#advlink_dlg.popup_statusbar}
{#advlink_dlg.popup_return}
{#advlink_dlg.advanced_props}
{#advlink_dlg.id}
{#advlink_dlg.style}
{#advlink_dlg.classes}
{#advlink_dlg.target_name}
{#advlink_dlg.langdir}
{#advlink_dlg.target_langcode}
{#advlink_dlg.langcode}
{#advlink_dlg.encoding}
{#advlink_dlg.mime}
{#advlink_dlg.rel}
{#advlink_dlg.rev}
{#advlink_dlg.tabindex}
{#advlink_dlg.accesskey}
{#advlink_dlg.event_props}

onfocus |
onblur |
onclick |
ondblclick |
onmousedown |
onmouseup |
onmouseover |
onmousemove |
onmouseout |
onkeypress |
onkeydown |
onkeyup |